@@ -1,13 +1,13 @@
-use crate::error::PGQueryError;
-use crate::parse::{parse_sql_query, parse_sql_query_json};
-use crate::rules::{
-    check_sql, CheckSQLError, RuleViolation, RuleViolationKind, Span, SquawkRule, ViolationMessage,
-    RULES,
-};
 use console::strip_ansi_codes;
 use console::style;
 use log::info;
 use serde::Serialize;
+use squawk_linter::rules::{
+    check_sql, CheckSQLError, RuleViolation, RuleViolationKind, Span, SquawkRule, ViolationMessage,
+    RULES,
+};
+use squawk_parser::error::PGQueryError;
+use squawk_parser::parse::{parse_sql_query, parse_sql_query_json};
 use std::convert::TryFrom;
 use std::fs::File;
 use std::io;
@@ -643,7 +643,6 @@ None found.
 mod test_reporter {
     use super::*;
 
-    use crate::rules::check_sql;
     use insta::{assert_debug_snapshot, assert_display_snapshot};
 
     #[test]
@@ -653,7 +652,8 @@ mod test_reporter {
 ALTER TABLE "core_foo" ADD COLUMN "bar" integer NOT NULL;
 SELECT 1;
 "#;
-        let violations = check_sql(sql, &[]).expect("valid sql should parse");
+        let violations =
+            check_sql(sql, &["prefer-robust-stmts".into()]).expect("valid sql should parse");
 
         let filename = "main.sql";
 
@@ -679,7 +679,8 @@ SELECT 1;
 ALTER TABLE "core_foo" ADD COLUMN "bar" integer NOT NULL;
 SELECT 1;
 "#;
-        let violations = check_sql(sql, &[]).expect("valid sql should parse");
+        let violations =
+            check_sql(sql, &["prefer-robust-stmts".into()]).expect("valid sql should parse");
         let filename = "main.sql";
         let mut buff = Vec::new();
 
@@ -715,7 +716,8 @@ SELECT 1;
 ALTER TABLE "core_foo" ADD COLUMN "bar" integer NOT NULL;
 SELECT 1;
 "#;
-        let violations = check_sql(sql, &[]).expect("valid sql should parse");
+        let violations =
+            check_sql(sql, &["prefer-robust-stmts".into()]).expect("valid sql should parse");
         let filename = "main.sql";
         let mut buff = Vec::new();
 
@@ -738,7 +740,8 @@ SELECT 1;
 ALTER TABLE "core_foo" ADD COLUMN "bar" integer NOT NULL;
 SELECT 1;
 "#;
-        let violations = check_sql(sql, &[]).expect("valid sql should parse");
+        let violations =
+            check_sql(sql, &["prefer-robust-stmts".into()]).expect("valid sql should parse");
 
         let filename = "main.sql";
         assert_debug_snapshot!(pretty_violations(violations, sql, filename));
@@ -749,7 +752,8 @@ SELECT 1;
     #[test]
     fn test_trimming_sql_newlines() {
         let sql = r#"ALTER TABLE "core_recipe" ADD COLUMN "foo" integer NOT NULL;"#;
-        let violations = check_sql(sql, &[]).expect("valid sql should parse");
+        let violations =
+            check_sql(sql, &["prefer-robust-stmts".into()]).expect("valid sql should parse");
 
         assert_debug_snapshot!(violations, @r###"
         [
